#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['twisted_raiser']

package_data = \
{'': ['*']}

install_requires = \
['cython-test-exception-raiser']

setup(name='twisted-raiser',
      version='2.0.0',
      description='Deprecated in favour of cython-test-exception-raiser',
      author='Thomas Grainger',
      author_email='twisted-raiser@graingert.co.uk',
      url='https://github.com/twisted/cython-test-exception-raiser',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
